==> pixelpay_sdk-2.0.3.tar.gz: lib/services/tokenization.dart <==
import 'package:pixelpay_sdk/base/response.dart';
import 'package:pixelpay_sdk/base/service_behaviour.dart';
import 'package:pixelpay_sdk/models/settings.dart';
import 'package:pixelpay_sdk/requests/card_tokenization.dart';

class Tokenization extends ServiceBehaviour {
  /// Initialize service
  Tokenization(Settings settings) : super(settings);

  /// Vault credit/debit card and obtain a token card identifier (T-* format)
  ///
  /// @param card
  /// @return
  /// @throws InvalidCredentialsException
  Future<Response?> vaultCard(CardTokenization card) {
    return send('tokenizationVaultCard',
        {'request': card.toJson(), 'settings': settings.toJson()});
  }

  /// Update credit/debit card by token card identifier
  ///
  /// @param token
  /// @param card
  /// @return
  /// @throws InvalidCredentialsException
  Future<Response?> updateCard(String token, CardTokenization card) {
    return send('tokenizationUpdateCard', {
      'token': token,
      'request': card.toJson(),
      'settings': settings.toJson()
    });
  }

  /// Show credit/debit card metadata by token card identifier
  ///
  /// @param token
  /// @return
  /// @throws InvalidCredentialsException
  Future<Response?> showCard(String token) {
    return send('tokenizationShowCard',
        {'token': token, 'settings': settings.toJson()});
  }

  /// Show credit/debit cards metadata by tokens card identifier
  ///
  /// @param tokens
  /// @return
  /// @throws InvalidCredentialsException
  Future<Response?> showCards(List<String> tokens) {
    return send('tokenizationShowCards',
        {'token': tokens, 'settings': settings.toJson()});
  }

  /// Delete credit/debit card metadata by token card identifier
  ///
  /// @param token
  /// @return
  /// @throws InvalidCredentialsException
  Future<Response?> deleteCard(String token) {
    return send('tokenizationDeleteCard',
        {'token': token, 'settings': settings.toJson()});
  }
}

==> pixelpay_sdk-2.0.4.tar.gz: lib/services/tokenization.dart <==
import 'package:pixelpay_sdk/base/request_behaviour.dart';
import 'package:pixelpay_sdk/base/response.dart';
import 'package:pixelpay_sdk/base/service_behaviour.dart';
import 'package:pixelpay_sdk/models/settings.dart';
import 'package:pixelpay_sdk/requests/card_tokenization.dart';

class Tokenization extends ServiceBehaviour {
  /// Initialize service
  Tokenization(Settings settings) : super(settings);

  /// Vault credit/debit card and obtain a token card identifier (T-* format)
  ///
  /// @param card
  /// @return
  /// @throws InvalidCredentialsException
  Future<Response?> vaultCard(CardTokenization card) {
    return send('tokenizationVaultCard',
        {'request': card.toJson(), 'settings': getSettings(card, settings)});
  }

  /// Update credit/debit card by token card identifier
  ///
  /// @param token
  /// @param card
  /// @return
  /// @throws InvalidCredentialsException
  Future<Response?> updateCard(String token, CardTokenization card) {
    return send('tokenizationUpdateCard', {
      'token': token,
      'request': card.toJson(),
      'settings': getSettings(card, settings)
    });
  }

  /// Show credit/debit card metadata by token card identifier
  ///
  /// @param token
  /// @return
  /// @throws InvalidCredentialsException
  Future<Response?> showCard(String token) {
    return send('tokenizationShowCard',
        {'token': token, 'settings': getSettings(RequestBehaviour(), settings)});
  }

  /// Show credit/debit cards metadata by tokens card identifier
  ///
  /// @param tokens
  /// @return
  /// @throws InvalidCredentialsException
  Future<Response?> showCards(List<String> tokens) {
    return send('tokenizationShowCards',
        {'token': tokens, 'settings': getSettings(RequestBehaviour(), settings)});
  }

  /// Delete credit/debit card metadata by token card identifier
  ///
  /// @param token
  /// @return
  /// @throws InvalidCredentialsException
  Future<Response?> deleteCard(String token) {
    return send('tokenizationDeleteCard',
        {'token': token, 'settings': getSettings(RequestBehaviour(), settings)});
  }
}
